﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "ScrollViewer 엘리먼트 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 스크롤 뷰어 조작 완료시 처리하기 - scrollViewer_ManipulationCompleted(sender, e)

        /// <summary>
        /// 스크롤 뷰어 조작 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void scrollViewer_ManipulationCompleted(object sender, ManipulationCompletedRoutedEventArgs e)
        {
            this.zoomSlider.Value = this.scrollViewer.ZoomFactor;
        }

        #endregion
        #region 확대/축소 모드 콤보 박스 선택 변경시 처리하기 - zoomModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 확대/축소 모드 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void zoomModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollViewer != null && this.zoomSlider != null)
            {
                if(sender is ComboBox comboBox)
                {
                    switch(comboBox.SelectedIndex)
                    {
                        case 0 : // Enabled

                            this.scrollViewer.ZoomMode = ZoomMode.Enabled;

                            this.zoomSlider.IsEnabled = true;

                            break;

                        case 1 : // Disabled
                        default : // Disabled

                            this.scrollViewer.ZoomMode = ZoomMode.Disabled;

                            this.scrollViewer.ChangeView(null, null, (float)1.0);

                            this.zoomSlider.Value     = 1;
                            this.zoomSlider.IsEnabled = false;

                            break;
                    }
                }
            }
        }

        #endregion
        #region 확대/축소 슬라이더 값 변경시 처리하기 - zoomSlider_ValueChanged(sender, e)

        /// <summary>
        /// 확대/축소 슬라이더 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void zoomSlider_ValueChanged(object sender, RangeBaseValueChangedEventArgs e)
        {
            if(this.scrollViewer != null)
            {
                this.scrollViewer.ChangeView(null, null, (float)e.NewValue);
            }
        }

        #endregion
        #region 수평 스크롤 모드 콤보 박스 선택 변경시 처리하기 - horizontalScrollModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 수평 스크롤 모드 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void horizontalScrollModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollViewer != null)
            {
                if(sender is ComboBox comboBox)
                {
                    switch(comboBox.SelectedIndex)
                    {
                        case 0  : this.scrollViewer.HorizontalScrollMode = ScrollMode.Auto;     break;
                        case 1  : this.scrollViewer.HorizontalScrollMode = ScrollMode.Enabled;  break;
                        case 2  : this.scrollViewer.HorizontalScrollMode = ScrollMode.Disabled; break;
                        default : this.scrollViewer.HorizontalScrollMode = ScrollMode.Enabled;  break;
                    }
                }
            }
        }

        #endregion
        #region 수직 스크롤 모드 콤보 박스 선택 변경시 처리하기 - verticalScrollModeComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 수직 스크롤 모드 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e"></param>
        private void verticalScrollModeComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollViewer != null)
            {
                if(sender is ComboBox comboBox)
                {
                    switch(comboBox.SelectedIndex)
                    {
                        case 0  : this.scrollViewer.VerticalScrollMode = ScrollMode.Auto;     break;
                        case 1  : this.scrollViewer.VerticalScrollMode = ScrollMode.Enabled;  break;
                        case 2  : this.scrollViewer.VerticalScrollMode = ScrollMode.Disabled; break;
                        default : this.scrollViewer.VerticalScrollMode = ScrollMode.Enabled;  break;
                    }
                }
            }
        }

        #endregion
        #region 수평 스크롤바 표시 콤보 박스 선택 변경시 처리하기 - horizontalScrollBarVisibilityComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 수평 스크롤바 표시 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void horizontalScrollBarVisibilityComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollViewer != null)
            {
                if(sender is ComboBox comboBox)
                {
                    switch(comboBox.SelectedIndex)
                    {
                        case 0  : this.scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Auto;     break;
                        case 1  : this.scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Visible;  break;
                        case 2  : this.scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Hidden;   break;
                        case 3  : this.scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Disabled; break;
                        default : this.scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Disabled; break;
                    }
                }
            }
        }

        #endregion
        #region 수직 스크롤바 표시 콤보 박스 선택 변경시 처리하기 - verticalScrollBarVisibilityComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 수직 스크롤바 표시 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void verticalScrollBarVisibilityComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.scrollViewer != null)
            {
                if(sender is ComboBox comboBox)
                {
                    switch(comboBox.SelectedIndex)
                    {
                        case 0  : this.scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Auto;     break;
                        case 1  : this.scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Visible;  break;
                        case 2  : this.scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Hidden;   break;
                        case 3  : this.scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Disabled; break;
                        default : this.scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Visible;  break;
                    }
                }
            }
        }

        #endregion
    }
}